/*
 *   GtkAudioScale
 *    
 *   Copyright (C) Robert Ham 2002 (node@users.sourceforge.net)
 *    
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __GTK_AUDIO_SCALE__
#define __GTK_AUDIO_SCALE__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#include <gtk/gtk.h>

#define GTK_TYPE_AUDIO_SCALE          gtk_audio_scale_get_type()
#define GTK_AUDIO_SCALE(obj)          GTK_CHECK_CAST (obj, gtk_audio_scale_get_type (), GtkAudioScale)
#define GTK_AUDIO_SCALE_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, gtk_audio_scale_get_type (), GtkAudioScaleClass)
#define GTK_IS_AUDIO_SCALE(obj)       GTK_CHECK_TYPE (obj, gtk_audio_scale_get_type ())

typedef struct _GtkAudioScale        GtkAudioScale;
typedef struct _GtkAudioScaleClass   GtkAudioScaleClass;

/* for the scale policy */
/*typedef enum
{
  GTK_AUDIO_SCALE_AT_LEAST,
  GTK_AUDIO_SCALE_AT_MOST,
  GTK_AUDIO_SCALE_AUTO
} GtkAudioScalePolicy;*/

/* for the adjustment mode */
typedef enum
{
  GTK_AUDIO_SCALE_NORMAL = 0,
  GTK_AUDIO_SCALE_UPPER,
  GTK_AUDIO_SCALE_LOWER
} GtkAudioScaleMode;


struct _GtkAudioScale
{
  GtkWidget widget;
  
  /* the main adjustment */
  GtkAdjustment * adjustment;
  
  /* signal handler ids for the adjustment */
  gulong adjustment_handlers[2];
  
  /* whether or not we're a logarithmic scale */
  gboolean logarithmic;
  
  /* the orientation */
  GtkOrientation orientation;
  
  /*
   * input handling
   */
  /* current adjustment mode */
  /* 0 = normal, 1 = lower zoom, 2 = upper zoom */
  GtkAudioScaleMode adjustment_mode;
  
  enum {
    /* outside the widget */
    GTK_AUDIO_SCALE_OUTSIDE,
    GTK_AUDIO_SCALE_ZOOM_UPPER_INDICATOR,
    GTK_AUDIO_SCALE_ZOOM_LOWER_INDICATOR,
    GTK_AUDIO_SCALE_TROUGH,
    GTK_AUDIO_SCALE_SLIDER,
    /* anywhere else in the widget */
    GTK_AUDIO_SCALE_WIDGET
  } mouse_position;
  
  /*
   * stuff for zooming
   */
  
  /* the upper and lower zoom values */
  gdouble zoom_upper;
  gdouble zoom_lower;
  
  
  
  /* the colours for the zoom indicators */
  GtkStyle * zoom_upper_style;
  GtkStyle * zoom_lower_style;
  
  /* the size of the zoom indicators */
  guint zoom_indicator_size;
  
  
  /* 
   * stuff for the scale
   */
  
  /* the scale tick policy; what we pay attention to
   * wrt the user's scale settings */
/*  GtkAudioScalePolicy scale_policy : GTK_AUDIO_SCALE_AUTO; */
  
  /* the user-defined number of major ticks */
/*  guint scale_ticks; */
  
  /* whether or not to draw the scale */
  gboolean scale_visible : TRUE;

  /*
   * widget layout
   */
  gint major_tick;
  gint minor_tick;
  /* height of scale text */
  gint scale_height;
  gint scale_width;
  /* whether or not to draw the scale vertically */
  gboolean scale_vert;
  gint trough_x;
  gint trough_y;
  gint trough_width;
  gint trough_height;
  gint slider_x;
  gint slider_y;
  gint slider_width;
  gint slider_height;
  gint zoom_lower_points[3];
  gint zoom_upper_points[3];
};

struct _GtkAudioScaleClass
{
  GtkWidgetClass parent_class;
  
  void (* zoom_upper_changed) ();
  void (* zoom_lower_changed) ();
  void (* value_changed) ();
};

GType gtk_audio_scale_get_type                         ();

gboolean gtk_audio_scale_get_logarithmic               (GtkAudioScale *);
void gtk_audio_scale_set_logarithmic                   (GtkAudioScale *, gboolean);
gboolean gtk_audio_scale_get_scale_visible             (GtkAudioScale *);
void gtk_audio_scale_set_scale_visible                 (GtkAudioScale *, gboolean);
/*GtkAudioScalePolicy gtk_audio_scale_get_scale_policy   (GtkAudioScale *);
void gtk_audio_scale_set_scale_policy                  (GtkAudioScale *, GtkAudioScalePolicy);
guint gtk_audio_scale_get_scale_ticks                  (GtkAudioScale *);
void gtk_audio_scale_set_scale_ticks                   (GtkAudioScale *, guint);*/
gdouble gtk_audio_scale_get_zoom_upper                 (GtkAudioScale *);
void gtk_audio_scale_set_zoom_upper                    (GtkAudioScale *, gdouble);
gdouble gtk_audio_scale_get_zoom_lower                 (GtkAudioScale *);
void gtk_audio_scale_set_zoom_lower                    (GtkAudioScale *, gdouble);
/*GtkAdjustment * gtk_audio_scale_get_adjustment         (GtkAudioScale *); */
void gtk_audio_scale_set_adjustment                    (GtkAudioScale *, GtkAdjustment *);
GtkStyle * gtk_audio_scale_get_zoom_upper_style        (GtkAudioScale *);
void gtk_audio_scale_set_zoom_upper_style              (GtkAudioScale *, GtkStyle *);
GtkStyle * gtk_audio_scale_get_zoom_lower_style        (GtkAudioScale *);
void gtk_audio_scale_set_zoom_lower_style              (GtkAudioScale *, GtkStyle *);
guint gtk_audio_scale_get_zoom_indicator_size          (GtkAudioScale *);
void gtk_audio_scale_set_zoom_indicator_size           (GtkAudioScale *, guint);
gdouble gtk_audio_scale_get_value                      (GtkAudioScale *);
void gtk_audio_scale_set_value                         (GtkAudioScale *, gdouble);
GtkOrientation gtk_audio_scale_get_orientation         (GtkAudioScale *);
void gtk_audio_scale_set_orientation                   (GtkAudioScale *, GtkOrientation);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __GTK_AUDIO_SCALE__ */
