/*
 *   JACK Rack
 *    
 *   Copyright (C) Robert Ham 2003 (node@users.sourceforge.net)
 *    
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __JR_PLUGIN_SETTINGS_H__
#define __JR_PLUGIN_SETTINGS_H__

#include <glib.h>
#include <jack/jack.h>
#include <ladspa.h>

#include "plugin_manager.h"
#include "plugin_desc.h"

typedef struct _settings settings_t;
typedef struct _settings_collection settings_collection_t;

struct _settings
{
  plugin_desc_t * desc;
  LADSPA_Data ** control_values;
  gboolean * locks;
  gboolean lock_all;
};

struct _settings_collection
{
  GSList * settings;
  jack_nframes_t sample_rate;
};

settings_collection_t * settings_collection_new     (plugin_mgr_t * plugin_mgr, jack_nframes_t sample_rate);
void                    settings_collection_destroy (settings_collection_t * collection);

void settings_collection_change_sample_rate (settings_collection_t * collection, jack_nframes_t sample_rate);      
settings_t * settings_collection_get_settings (settings_collection_t * collection, unsigned long plugin_id);



settings_t * settings_new     (plugin_desc_t * desc, jack_nframes_t sample_rate);
void         settings_destroy (settings_t * settings);

void settings_set_control_value (settings_t * settings, unsigned long control_index, unsigned long copy, LADSPA_Data value);
void settings_set_lock          (settings_t * settings, unsigned long control_index, gboolean locked);
void settings_set_lock_all      (settings_t * settings, gboolean lock_all);

LADSPA_Data settings_get_control_value (const settings_t * settings, unsigned long control_index, unsigned long copy);
gboolean    settings_get_lock          (const settings_t * settings, unsigned long control_index);
gboolean    settings_get_lock_all      (const settings_t * settings);

void settings_change_sample_rate (settings_t * settings, LADSPA_Data old_sample_rate, LADSPA_Data new_sample_rate);

#endif /* __JR_PLUGIN_SETTINGS_H__ */
